import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * An example resource that creates an Azure Storage account along with a Blob container.
 *
 * @schema CfnBlobStorageProps
 */
export interface CfnBlobStorageProps {
    /**
     * Subscription ID of the Azure Account.
     *
     * @schema CfnBlobStorageProps#AzureSubscriptionId
     */
    readonly azureSubscriptionId: string;
    /**
     * App ID CloudFormation will use to access Azure.
     *
     * @schema CfnBlobStorageProps#AzureClientId
     */
    readonly azureClientId: string;
    /**
     * Directory ID CloudFormation will use to access Azure.
     *
     * @schema CfnBlobStorageProps#AzureTenantId
     */
    readonly azureTenantId: string;
    /**
     * Client credentials CloudFormation will use to authenticate to Azure and access services.
     *
     * @schema CfnBlobStorageProps#AzureClientSecret
     */
    readonly azureClientSecret: string;
}
/**
 * Converts an object of type 'CfnBlobStorageProps' to JSON representation.
 */
export declare function toJson_CfnBlobStorageProps(obj: CfnBlobStorageProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `POC::Azure::BlobStorage`
 *
 * @cloudformationResource POC::Azure::BlobStorage
 * @stability external
 * @link http://unknown-url
 */
export declare class CfnBlobStorage extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "POC::Azure::BlobStorage";
    /**
     * Resource props.
     */
    readonly props: CfnBlobStorageProps;
    /**
     * Attribute `POC::Azure::BlobStorage.AzureBlobStorageAccountName`
     * @link http://unknown-url
     */
    readonly attrAzureBlobStorageAccountName: string;
    /**
     * Attribute `POC::Azure::BlobStorage.AzureBlobContainerUrl`
     * @link http://unknown-url
     */
    readonly attrAzureBlobContainerUrl: string;
    /**
     * Attribute `POC::Azure::BlobStorage.AzureResourceGroup`
     * @link http://unknown-url
     */
    readonly attrAzureResourceGroup: string;
    /**
     * Create a new `POC::Azure::BlobStorage`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnBlobStorageProps);
}
